@@ -32,5 +32,9 @@ class RiteAidAPI:
             quote(phone),
         )
         async with aiohttp.ClientSession() as session:
-            async with session.post(REFILL_RX_URL, data=form) as resp:
+            async with session.post(REFILL_RX_URL, data=form, headers={
+                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.82 Safari/537.36",
+                "Content-Type": "pplication/x-www-form-urlencoded; charset=UTF-8",
+                "Referer": "https://www.riteaid.com/pharmacy/services/prescription-refills/online-prescription-refills"
+            }) as resp:
                 return await resp.json()
\ No newline at end of file
